==> jc-1.4.0.tar.gz: soot/jimple/internal/JInterfaceInvokeExpr.h <==
// public class soot.jimple.internal.JInterfaceInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 9a153470fbee82fc soot_jimple_internal_AbstractInterfaceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class e6be6fcad19f3456 soot_jimple_internal_JInterfaceInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInterfaceInvokeExpr

#include "soot/jimple/internal/AbstractInterfaceInvokeExpr.h"

#ifndef _JC_soot_jimple_internal_JInterfaceInvokeExpr_H_
#define _JC_soot_jimple_internal_JInterfaceInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_refs	_jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_nonrefs	_jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$refs	_jc_soot_jimple_internal_JInterfaceInvokeExpr$refs;
typedef struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$nonrefs	_jc_soot_jimple_internal_JInterfaceInvokeExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$object	_jc_soot_jimple_internal_JInterfaceInvokeExpr$object;

typedef const struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$vmethods	_jc_soot_jimple_internal_JInterfaceInvokeExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$vtable	_jc_soot_jimple_internal_JInterfaceInvokeExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$vtype	_jc_soot_jimple_internal_JInterfaceInvokeExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JInterfaceInvokeExpr$method$_init$737b9105a0ba7cab(_jc_env *, struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JInterfaceInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JInterfaceInvokeExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractInterfaceInvokeExpr$vmethods	soot_jimple_internal_AbstractInterfaceInvokeExpr;
	_jc_soot_jimple_internal_JInterfaceInvokeExpr$vmethods	soot_jimple_internal_JInterfaceInvokeExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JInterfaceInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$refs {
    _jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_refs	soot_jimple_internal_JInterfaceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInterfaceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInterfaceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInterfaceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInterfaceInvokeExpr;
    _jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_nonrefs	soot_jimple_internal_JInterfaceInvokeExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$object {
	_jc_soot_jimple_internal_JInterfaceInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JInterfaceInvokeExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JInterfaceInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JInterfaceInvokeExpr$vtype _jc_soot_jimple_internal_JInterfaceInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JInterfaceInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JInterfaceInvokeExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JInterfaceInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JInterfaceInvokeExpr.h <==
// public class soot.jimple.internal.JInterfaceInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 9a153470fbee82fc soot_jimple_internal_AbstractInterfaceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class e6be6fcad19f3456 soot_jimple_internal_JInterfaceInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInterfaceInvokeExpr

#include "soot/jimple/internal/AbstractInterfaceInvokeExpr.h"

#ifndef _JC_soot_jimple_internal_JInterfaceInvokeExpr_H_
#define _JC_soot_jimple_internal_JInterfaceInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_refs	_jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_nonrefs	_jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$refs	_jc_soot_jimple_internal_JInterfaceInvokeExpr$refs;
typedef struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$nonrefs	_jc_soot_jimple_internal_JInterfaceInvokeExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$object	_jc_soot_jimple_internal_JInterfaceInvokeExpr$object;

typedef const struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$vmethods	_jc_soot_jimple_internal_JInterfaceInvokeExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$vtable	_jc_soot_jimple_internal_JInterfaceInvokeExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$vtype	_jc_soot_jimple_internal_JInterfaceInvokeExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JInterfaceInvokeExpr$method$_init$737b9105a0ba7cab(_jc_env *, struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JInterfaceInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JInterfaceInvokeExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractInterfaceInvokeExpr$vmethods	soot_jimple_internal_AbstractInterfaceInvokeExpr;
	_jc_soot_jimple_internal_JInterfaceInvokeExpr$vmethods	soot_jimple_internal_JInterfaceInvokeExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JInterfaceInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$refs {
    _jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_refs	soot_jimple_internal_JInterfaceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInterfaceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInterfaceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInterfaceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInterfaceInvokeExpr;
    _jc_soot_jimple_internal_JInterfaceInvokeExpr$sub_nonrefs	soot_jimple_internal_JInterfaceInvokeExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JInterfaceInvokeExpr$object {
	_jc_soot_jimple_internal_JInterfaceInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JInterfaceInvokeExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JInterfaceInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JInterfaceInvokeExpr$vtype _jc_soot_jimple_internal_JInterfaceInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JInterfaceInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JInterfaceInvokeExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JInterfaceInvokeExpr_H_ */
